@@ -3,10 +3,7 @@ import pkg_resources
 from pathlib import Path
 from pkg_resources import resource_string
 
-#Pour inclure les fichiers de l'environnement
-cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"grid")))
-if cmd_subfolder_grid not in sys.path:
-    sys.path.insert(0, cmd_subfolder_grid)
+sys.path.insert(0, 'donatellopyzza/grid')
 
 from parser import Parser
 from grid import Grid
